# [m](https://jmlopez-rod.github.io/m/)

## install

```
pip install jmlopez-m
```

## development

Start by opening the devcontainer in VSCode. Once there open a terminal and run

```
poetry install
```

and

```
pnpm install
```

to install the dependencies.

There are several make targets to run. The most important one is
`make ci-checks`. Run that since it is the closest to what the CI will run.
